@@ -10,7 +10,182 @@ import publication
 from jsii.python import classproperty
 
 import aws_cdk.core
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-sagemaker", "1.1.0", __name__, "aws-sagemaker@1.1.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-sagemaker", "1.14.0", __name__, "aws-sagemaker@1.14.0.jsii.tgz")
+class CfnCodeRepository(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-sagemaker.CfnCodeRepository"):
+    """A CloudFormation ``AWS::SageMaker::CodeRepository``.
+
+    see
+    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-coderepository.html
+    cloudformationResource:
+    :cloudformationResource:: AWS::SageMaker::CodeRepository
+    """
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, git_config: typing.Union["GitConfigProperty", aws_cdk.core.IResolvable], code_repository_name: typing.Optional[str]=None) -> None:
+        """Create a new ``AWS::SageMaker::CodeRepository``.
+
+        :param scope: - scope in which this resource is defined.
+        :param id: - scoped id of the resource.
+        :param props: - resource properties.
+        :param git_config: ``AWS::SageMaker::CodeRepository.GitConfig``.
+        :param code_repository_name: ``AWS::SageMaker::CodeRepository.CodeRepositoryName``.
+        """
+        props = CfnCodeRepositoryProps(git_config=git_config, code_repository_name=code_repository_name)
+
+        jsii.create(CfnCodeRepository, self, [scope, id, props])
+
+    @jsii.member(jsii_name="renderProperties")
+    def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
+        """
+        :param props: -
+        """
+        return jsii.invoke(self, "renderProperties", [props])
+
+    @classproperty
+    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
+    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+        """The CloudFormation resource type name for this resource class."""
+        return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
+
+    @property
+    @jsii.member(jsii_name="attrCodeRepositoryName")
+    def attr_code_repository_name(self) -> str:
+        """
+        cloudformationAttribute:
+        :cloudformationAttribute:: CodeRepositoryName
+        """
+        return jsii.get(self, "attrCodeRepositoryName")
+
+    @property
+    @jsii.member(jsii_name="cfnProperties")
+    def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
+        return jsii.get(self, "cfnProperties")
+
+    @property
+    @jsii.member(jsii_name="gitConfig")
+    def git_config(self) -> typing.Union["GitConfigProperty", aws_cdk.core.IResolvable]:
+        """``AWS::SageMaker::CodeRepository.GitConfig``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-coderepository.html#cfn-sagemaker-coderepository-gitconfig
+        """
+        return jsii.get(self, "gitConfig")
+
+    @git_config.setter
+    def git_config(self, value: typing.Union["GitConfigProperty", aws_cdk.core.IResolvable]):
+        return jsii.set(self, "gitConfig", value)
+
+    @property
+    @jsii.member(jsii_name="codeRepositoryName")
+    def code_repository_name(self) -> typing.Optional[str]:
+        """``AWS::SageMaker::CodeRepository.CodeRepositoryName``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-coderepository.html#cfn-sagemaker-coderepository-coderepositoryname
+        """
+        return jsii.get(self, "codeRepositoryName")
+
+    @code_repository_name.setter
+    def code_repository_name(self, value: typing.Optional[str]):
+        return jsii.set(self, "codeRepositoryName", value)
+
+    @jsii.data_type(jsii_type="@aws-cdk/aws-sagemaker.CfnCodeRepository.GitConfigProperty", jsii_struct_bases=[], name_mapping={'repository_url': 'repositoryUrl', 'branch': 'branch', 'secret_arn': 'secretArn'})
+    class GitConfigProperty():
+        def __init__(self, *, repository_url: str, branch: typing.Optional[str]=None, secret_arn: typing.Optional[str]=None):
+            """
+            :param repository_url: ``CfnCodeRepository.GitConfigProperty.RepositoryUrl``.
+            :param branch: ``CfnCodeRepository.GitConfigProperty.Branch``.
+            :param secret_arn: ``CfnCodeRepository.GitConfigProperty.SecretArn``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-sagemaker-coderepository-gitconfig.html
+            """
+            self._values = {
+                'repository_url': repository_url,
+            }
+            if branch is not None: self._values["branch"] = branch
+            if secret_arn is not None: self._values["secret_arn"] = secret_arn
+
+        @property
+        def repository_url(self) -> str:
+            """``CfnCodeRepository.GitConfigProperty.RepositoryUrl``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-sagemaker-coderepository-gitconfig.html#cfn-sagemaker-coderepository-gitconfig-repositoryurl
+            """
+            return self._values.get('repository_url')
+
+        @property
+        def branch(self) -> typing.Optional[str]:
+            """``CfnCodeRepository.GitConfigProperty.Branch``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-sagemaker-coderepository-gitconfig.html#cfn-sagemaker-coderepository-gitconfig-branch
+            """
+            return self._values.get('branch')
+
+        @property
+        def secret_arn(self) -> typing.Optional[str]:
+            """``CfnCodeRepository.GitConfigProperty.SecretArn``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-sagemaker-coderepository-gitconfig.html#cfn-sagemaker-coderepository-gitconfig-secretarn
+            """
+            return self._values.get('secret_arn')
+
+        def __eq__(self, rhs) -> bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs) -> bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return 'GitConfigProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+
+
+
+@jsii.data_type(jsii_type="@aws-cdk/aws-sagemaker.CfnCodeRepositoryProps", jsii_struct_bases=[], name_mapping={'git_config': 'gitConfig', 'code_repository_name': 'codeRepositoryName'})
+class CfnCodeRepositoryProps():
+    def __init__(self, *, git_config: typing.Union["CfnCodeRepository.GitConfigProperty", aws_cdk.core.IResolvable], code_repository_name: typing.Optional[str]=None):
+        """Properties for defining a ``AWS::SageMaker::CodeRepository``.
+
+        :param git_config: ``AWS::SageMaker::CodeRepository.GitConfig``.
+        :param code_repository_name: ``AWS::SageMaker::CodeRepository.CodeRepositoryName``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-coderepository.html
+        """
+        self._values = {
+            'git_config': git_config,
+        }
+        if code_repository_name is not None: self._values["code_repository_name"] = code_repository_name
+
+    @property
+    def git_config(self) -> typing.Union["CfnCodeRepository.GitConfigProperty", aws_cdk.core.IResolvable]:
+        """``AWS::SageMaker::CodeRepository.GitConfig``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-coderepository.html#cfn-sagemaker-coderepository-gitconfig
+        """
+        return self._values.get('git_config')
+
+    @property
+    def code_repository_name(self) -> typing.Optional[str]:
+        """``AWS::SageMaker::CodeRepository.CodeRepositoryName``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-coderepository.html#cfn-sagemaker-coderepository-coderepositoryname
+        """
+        return self._values.get('code_repository_name')
+
+    def __eq__(self, rhs) -> bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs) -> bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return 'CfnCodeRepositoryProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+
+
 class CfnEndpoint(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-sagemaker.CfnEndpoint"):
     """A CloudFormation ``AWS::SageMaker::Endpoint``.
 
@@ -107,7 +282,7 @@ class CfnEndpointConfig(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
     cloudformationResource:
     :cloudformationResource:: AWS::SageMaker::EndpointConfig
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, production_variants: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["ProductionVariantProperty", aws_cdk.core.IResolvable]]], endpoint_config_name: typing.Optional[str]=None, kms_key_id: typing.Optional[str]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, production_variants: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ProductionVariantProperty"]]], endpoint_config_name: typing.Optional[str]=None, kms_key_id: typing.Optional[str]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None) -> None:
         """Create a new ``AWS::SageMaker::EndpointConfig``.
 
         :param scope: - scope in which this resource is defined.
@@ -161,7 +336,7 @@ class CfnEndpointConfig(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
 
     @property
     @jsii.member(jsii_name="productionVariants")
-    def production_variants(self) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["ProductionVariantProperty", aws_cdk.core.IResolvable]]]:
+    def production_variants(self) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ProductionVariantProperty"]]]:
         """``AWS::SageMaker::EndpointConfig.ProductionVariants``.
 
         see
@@ -170,7 +345,7 @@ class CfnEndpointConfig(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
         return jsii.get(self, "productionVariants")
 
     @production_variants.setter
-    def production_variants(self, value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["ProductionVariantProperty", aws_cdk.core.IResolvable]]]):
+    def production_variants(self, value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ProductionVariantProperty"]]]):
         return jsii.set(self, "productionVariants", value)
 
     @property
@@ -291,7 +466,7 @@ class CfnEndpointConfig(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-sagemaker.CfnEndpointConfigProps", jsii_struct_bases=[], name_mapping={'production_variants': 'productionVariants', 'endpoint_config_name': 'endpointConfigName', 'kms_key_id': 'kmsKeyId', 'tags': 'tags'})
 class CfnEndpointConfigProps():
-    def __init__(self, *, production_variants: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnEndpointConfig.ProductionVariantProperty", aws_cdk.core.IResolvable]]], endpoint_config_name: typing.Optional[str]=None, kms_key_id: typing.Optional[str]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None):
+    def __init__(self, *, production_variants: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnEndpointConfig.ProductionVariantProperty"]]], endpoint_config_name: typing.Optional[str]=None, kms_key_id: typing.Optional[str]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None):
         """Properties for defining a ``AWS::SageMaker::EndpointConfig``.
 
         :param production_variants: ``AWS::SageMaker::EndpointConfig.ProductionVariants``.
@@ -310,7 +485,7 @@ class CfnEndpointConfigProps():
         if tags is not None: self._values["tags"] = tags
 
     @property
-    def production_variants(self) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnEndpointConfig.ProductionVariantProperty", aws_cdk.core.IResolvable]]]:
+    def production_variants(self) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnEndpointConfig.ProductionVariantProperty"]]]:
         """``AWS::SageMaker::EndpointConfig.ProductionVariants``.
 
         see
@@ -1347,6 +1522,319 @@ class CfnNotebookInstanceProps():
         return 'CfnNotebookInstanceProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
-__all__ = ["CfnEndpoint", "CfnEndpointConfig", "CfnEndpointConfigProps", "CfnEndpointProps", "CfnModel", "CfnModelProps", "CfnNotebookInstance", "CfnNotebookInstanceLifecycleConfig", "CfnNotebookInstanceLifecycleConfigProps", "CfnNotebookInstanceProps", "__jsii_assembly__"]
+class CfnWorkteam(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-sagemaker.CfnWorkteam"):
+    """A CloudFormation ``AWS::SageMaker::Workteam``.
+
+    see
+    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-workteam.html
+    cloudformationResource:
+    :cloudformationResource:: AWS::SageMaker::Workteam
+    """
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, description: typing.Optional[str]=None, member_definitions: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "MemberDefinitionProperty"]]]]]=None, notification_configuration: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["NotificationConfigurationProperty"]]]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None, workteam_name: typing.Optional[str]=None) -> None:
+        """Create a new ``AWS::SageMaker::Workteam``.
+
+        :param scope: - scope in which this resource is defined.
+        :param id: - scoped id of the resource.
+        :param props: - resource properties.
+        :param description: ``AWS::SageMaker::Workteam.Description``.
+        :param member_definitions: ``AWS::SageMaker::Workteam.MemberDefinitions``.
+        :param notification_configuration: ``AWS::SageMaker::Workteam.NotificationConfiguration``.
+        :param tags: ``AWS::SageMaker::Workteam.Tags``.
+        :param workteam_name: ``AWS::SageMaker::Workteam.WorkteamName``.
+        """
+        props = CfnWorkteamProps(description=description, member_definitions=member_definitions, notification_configuration=notification_configuration, tags=tags, workteam_name=workteam_name)
+
+        jsii.create(CfnWorkteam, self, [scope, id, props])
+
+    @jsii.member(jsii_name="renderProperties")
+    def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
+        """
+        :param props: -
+        """
+        return jsii.invoke(self, "renderProperties", [props])
+
+    @classproperty
+    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
+    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+        """The CloudFormation resource type name for this resource class."""
+        return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
+
+    @property
+    @jsii.member(jsii_name="attrWorkteamName")
+    def attr_workteam_name(self) -> str:
+        """
+        cloudformationAttribute:
+        :cloudformationAttribute:: WorkteamName
+        """
+        return jsii.get(self, "attrWorkteamName")
+
+    @property
+    @jsii.member(jsii_name="cfnProperties")
+    def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
+        return jsii.get(self, "cfnProperties")
+
+    @property
+    @jsii.member(jsii_name="tags")
+    def tags(self) -> aws_cdk.core.TagManager:
+        """``AWS::SageMaker::Workteam.Tags``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-workteam.html#cfn-sagemaker-workteam-tags
+        """
+        return jsii.get(self, "tags")
+
+    @property
+    @jsii.member(jsii_name="description")
+    def description(self) -> typing.Optional[str]:
+        """``AWS::SageMaker::Workteam.Description``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-workteam.html#cfn-sagemaker-workteam-description
+        """
+        return jsii.get(self, "description")
+
+    @description.setter
+    def description(self, value: typing.Optional[str]):
+        return jsii.set(self, "description", value)
+
+    @property
+    @jsii.member(jsii_name="memberDefinitions")
+    def member_definitions(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "MemberDefinitionProperty"]]]]]:
+        """``AWS::SageMaker::Workteam.MemberDefinitions``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-workteam.html#cfn-sagemaker-workteam-memberdefinitions
+        """
+        return jsii.get(self, "memberDefinitions")
+
+    @member_definitions.setter
+    def member_definitions(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "MemberDefinitionProperty"]]]]]):
+        return jsii.set(self, "memberDefinitions", value)
+
+    @property
+    @jsii.member(jsii_name="notificationConfiguration")
+    def notification_configuration(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["NotificationConfigurationProperty"]]]:
+        """``AWS::SageMaker::Workteam.NotificationConfiguration``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-workteam.html#cfn-sagemaker-workteam-notificationconfiguration
+        """
+        return jsii.get(self, "notificationConfiguration")
+
+    @notification_configuration.setter
+    def notification_configuration(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["NotificationConfigurationProperty"]]]):
+        return jsii.set(self, "notificationConfiguration", value)
+
+    @property
+    @jsii.member(jsii_name="workteamName")
+    def workteam_name(self) -> typing.Optional[str]:
+        """``AWS::SageMaker::Workteam.WorkteamName``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-workteam.html#cfn-sagemaker-workteam-workteamname
+        """
+        return jsii.get(self, "workteamName")
+
+    @workteam_name.setter
+    def workteam_name(self, value: typing.Optional[str]):
+        return jsii.set(self, "workteamName", value)
+
+    @jsii.data_type(jsii_type="@aws-cdk/aws-sagemaker.CfnWorkteam.CognitoMemberDefinitionProperty", jsii_struct_bases=[], name_mapping={'cognito_client_id': 'cognitoClientId', 'cognito_user_group': 'cognitoUserGroup', 'cognito_user_pool': 'cognitoUserPool'})
+    class CognitoMemberDefinitionProperty():
+        def __init__(self, *, cognito_client_id: str, cognito_user_group: str, cognito_user_pool: str):
+            """
+            :param cognito_client_id: ``CfnWorkteam.CognitoMemberDefinitionProperty.CognitoClientId``.
+            :param cognito_user_group: ``CfnWorkteam.CognitoMemberDefinitionProperty.CognitoUserGroup``.
+            :param cognito_user_pool: ``CfnWorkteam.CognitoMemberDefinitionProperty.CognitoUserPool``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-sagemaker-workteam-cognitomemberdefinition.html
+            """
+            self._values = {
+                'cognito_client_id': cognito_client_id,
+                'cognito_user_group': cognito_user_group,
+                'cognito_user_pool': cognito_user_pool,
+            }
+
+        @property
+        def cognito_client_id(self) -> str:
+            """``CfnWorkteam.CognitoMemberDefinitionProperty.CognitoClientId``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-sagemaker-workteam-cognitomemberdefinition.html#cfn-sagemaker-workteam-cognitomemberdefinition-cognitoclientid
+            """
+            return self._values.get('cognito_client_id')
+
+        @property
+        def cognito_user_group(self) -> str:
+            """``CfnWorkteam.CognitoMemberDefinitionProperty.CognitoUserGroup``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-sagemaker-workteam-cognitomemberdefinition.html#cfn-sagemaker-workteam-cognitomemberdefinition-cognitousergroup
+            """
+            return self._values.get('cognito_user_group')
+
+        @property
+        def cognito_user_pool(self) -> str:
+            """``CfnWorkteam.CognitoMemberDefinitionProperty.CognitoUserPool``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-sagemaker-workteam-cognitomemberdefinition.html#cfn-sagemaker-workteam-cognitomemberdefinition-cognitouserpool
+            """
+            return self._values.get('cognito_user_pool')
+
+        def __eq__(self, rhs) -> bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs) -> bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return 'CognitoMemberDefinitionProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+
+
+    @jsii.data_type(jsii_type="@aws-cdk/aws-sagemaker.CfnWorkteam.MemberDefinitionProperty", jsii_struct_bases=[], name_mapping={'cognito_member_definition': 'cognitoMemberDefinition'})
+    class MemberDefinitionProperty():
+        def __init__(self, *, cognito_member_definition: typing.Union[aws_cdk.core.IResolvable, "CfnWorkteam.CognitoMemberDefinitionProperty"]):
+            """
+            :param cognito_member_definition: ``CfnWorkteam.MemberDefinitionProperty.CognitoMemberDefinition``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-sagemaker-workteam-memberdefinition.html
+            """
+            self._values = {
+                'cognito_member_definition': cognito_member_definition,
+            }
+
+        @property
+        def cognito_member_definition(self) -> typing.Union[aws_cdk.core.IResolvable, "CfnWorkteam.CognitoMemberDefinitionProperty"]:
+            """``CfnWorkteam.MemberDefinitionProperty.CognitoMemberDefinition``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-sagemaker-workteam-memberdefinition.html#cfn-sagemaker-workteam-memberdefinition-cognitomemberdefinition
+            """
+            return self._values.get('cognito_member_definition')
+
+        def __eq__(self, rhs) -> bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs) -> bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return 'MemberDefinitionProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+
+
+    @jsii.data_type(jsii_type="@aws-cdk/aws-sagemaker.CfnWorkteam.NotificationConfigurationProperty", jsii_struct_bases=[], name_mapping={'notification_topic_arn': 'notificationTopicArn'})
+    class NotificationConfigurationProperty():
+        def __init__(self, *, notification_topic_arn: str):
+            """
+            :param notification_topic_arn: ``CfnWorkteam.NotificationConfigurationProperty.NotificationTopicArn``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-sagemaker-workteam-notificationconfiguration.html
+            """
+            self._values = {
+                'notification_topic_arn': notification_topic_arn,
+            }
+
+        @property
+        def notification_topic_arn(self) -> str:
+            """``CfnWorkteam.NotificationConfigurationProperty.NotificationTopicArn``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-sagemaker-workteam-notificationconfiguration.html#cfn-sagemaker-workteam-notificationconfiguration-notificationtopicarn
+            """
+            return self._values.get('notification_topic_arn')
+
+        def __eq__(self, rhs) -> bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs) -> bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return 'NotificationConfigurationProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+
+
+
+@jsii.data_type(jsii_type="@aws-cdk/aws-sagemaker.CfnWorkteamProps", jsii_struct_bases=[], name_mapping={'description': 'description', 'member_definitions': 'memberDefinitions', 'notification_configuration': 'notificationConfiguration', 'tags': 'tags', 'workteam_name': 'workteamName'})
+class CfnWorkteamProps():
+    def __init__(self, *, description: typing.Optional[str]=None, member_definitions: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnWorkteam.MemberDefinitionProperty"]]]]]=None, notification_configuration: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkteam.NotificationConfigurationProperty"]]]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None, workteam_name: typing.Optional[str]=None):
+        """Properties for defining a ``AWS::SageMaker::Workteam``.
+
+        :param description: ``AWS::SageMaker::Workteam.Description``.
+        :param member_definitions: ``AWS::SageMaker::Workteam.MemberDefinitions``.
+        :param notification_configuration: ``AWS::SageMaker::Workteam.NotificationConfiguration``.
+        :param tags: ``AWS::SageMaker::Workteam.Tags``.
+        :param workteam_name: ``AWS::SageMaker::Workteam.WorkteamName``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-workteam.html
+        """
+        self._values = {
+        }
+        if description is not None: self._values["description"] = description
+        if member_definitions is not None: self._values["member_definitions"] = member_definitions
+        if notification_configuration is not None: self._values["notification_configuration"] = notification_configuration
+        if tags is not None: self._values["tags"] = tags
+        if workteam_name is not None: self._values["workteam_name"] = workteam_name
+
+    @property
+    def description(self) -> typing.Optional[str]:
+        """``AWS::SageMaker::Workteam.Description``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-workteam.html#cfn-sagemaker-workteam-description
+        """
+        return self._values.get('description')
+
+    @property
+    def member_definitions(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnWorkteam.MemberDefinitionProperty"]]]]]:
+        """``AWS::SageMaker::Workteam.MemberDefinitions``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-workteam.html#cfn-sagemaker-workteam-memberdefinitions
+        """
+        return self._values.get('member_definitions')
+
+    @property
+    def notification_configuration(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkteam.NotificationConfigurationProperty"]]]:
+        """``AWS::SageMaker::Workteam.NotificationConfiguration``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-workteam.html#cfn-sagemaker-workteam-notificationconfiguration
+        """
+        return self._values.get('notification_configuration')
+
+    @property
+    def tags(self) -> typing.Optional[typing.List[aws_cdk.core.CfnTag]]:
+        """``AWS::SageMaker::Workteam.Tags``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-workteam.html#cfn-sagemaker-workteam-tags
+        """
+        return self._values.get('tags')
+
+    @property
+    def workteam_name(self) -> typing.Optional[str]:
+        """``AWS::SageMaker::Workteam.WorkteamName``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-workteam.html#cfn-sagemaker-workteam-workteamname
+        """
+        return self._values.get('workteam_name')
+
+    def __eq__(self, rhs) -> bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs) -> bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return 'CfnWorkteamProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+
+
+__all__ = ["CfnCodeRepository", "CfnCodeRepositoryProps", "CfnEndpoint", "CfnEndpointConfig", "CfnEndpointConfigProps", "CfnEndpointProps", "CfnModel", "CfnModelProps", "CfnNotebookInstance", "CfnNotebookInstanceLifecycleConfig", "CfnNotebookInstanceLifecycleConfigProps", "CfnNotebookInstanceProps", "CfnWorkteam", "CfnWorkteamProps", "__jsii_assembly__"]
 
 publication.publish()
